#ifndef AUDIO_H
#define AUDIO_H

#include <QObject>
#include <QFile>
#include <phonon/MediaObject>
#include <phonon/MediaSource>
#include <reader.h>
/*extern "C"
{
    #include "flite.h"
}*/


class Audio : public QObject
{
    Q_OBJECT
public:
    explicit Audio(QObject *parent = 0);
    void createWav(QString filename);
    void play();
    void pause();

signals:

public slots:
    void audioFinished();
    void threadFinished();

private:
    QString file;
    QFile *audioFile;
    Phonon::MediaObject *music;
    Reader *reader;


signals:
    void finished();
    void wavCreated();

};

#endif // AUDIO_H
